@@ -1,8 +1,8 @@
 ## ----message=FALSE------------------------------------------------------------
 library(htmltab)
 
-url <- "http://christianrubba.com/cran/htmltab/vignette/Demography%20of%20the%20United%20Kingdom%20-%20Wikipedia.html"
-ukLang <- htmltab(doc = url, which = "//th[text() = 'Ability']/ancestor::table")
+url <- "https://en.wikipedia.org/w/index.php?title=Languages_of_the_United_Kingdom&oldid=1005083039"
+ukLang <- htmltab(doc = url, which = "//th[text() = 'Ability\n']/ancestor::table")
 head(ukLang)
 
 ## ----message=FALSE------------------------------------------------------------
@@ -15,7 +15,7 @@ ukLang <- separate(ukLang, key, into = c("region", "language", "statistic"), sep
 head(ukLang)
 
 ## -----------------------------------------------------------------------------
-url <- "http://christianrubba.com/cran/htmltab/vignette/New%20Zealand%20general%20election,%202002%20-%20Wikipedia.html"
+url <- "https://en.wikipedia.org/w/index.php?title=2002_New_Zealand_general_election&oldid=1008475471"
 xp <- "//caption[starts-with(text(), 'Electorate results')]/ancestor::table"
 body_xp <- "//tr[./td[not(@colspan = '8')]]"
 
